
// Setup signature pad.
var wrapper = document.getElementById("signature-pad");

var clearButton = wrapper.querySelector("[data-action=clear]");

var changeColorButton = wrapper.querySelector("[data-action=change-color]");

var undoButton = wrapper.querySelector("[data-action=undo]");

//var saveJPGButton = wrapper.querySelector("[data-action=save-jpg]");

//var saveSVGButton = wrapper.querySelector("[data-action=save-svg]");

var canvas = wrapper.querySelector("canvas");

var signaturePad = new SignaturePad(canvas, {
    // It's Necessary to use an opaque color when saving image as JPEG;
    // this option can be omitted if only saving as PNG or SVGsave
    backgroundColor: 'rgb(255, 255, 255)'
});

// Setup initial pad.
var initialPadWrapper = document.getElementById("initial-pad");

var initialPadClearButton = initialPadWrapper.querySelector("[data-action=clear]");

var initialPadUndoButton = initialPadWrapper.querySelector("[data-action=undo]");

var initialCanvas = initialPadWrapper.querySelector("canvas");

var initialPad = new SignaturePad(initialCanvas, {
    // It's Necessary to use an opaque color when saving image as JPEG;
    // this option can be omitted if only saving as PNG or SVGsave
    backgroundColor: 'rgb(255, 255, 255)'
});

// Adjust canvas coordinate space taking into account pixel ratio,
// to make it look crisp on mobile devices.
// This also causes canvas to be cleared.
function resizeCanvas() {
    // When zoomed out to less than 100%, for some very strange reason,
    // some browsers report devicePixelRatio as less than 1
    // and only part of the canvas is cleared then.
    var ratio = Math.max(window.devicePixelRatio || 1, 1);

    // This part causes the canvas to be cleared
    canvas.width = canvas.offsetWidth * ratio;
    canvas.height = canvas.offsetHeight * ratio;
    canvas.getContext("2d").scale(ratio, ratio);

    // This library does not listen for canvas changes, so after the canvas is automatically
    // cleared by the browser, SignaturePad#isEmpty might still return false, even though the
    // canvas looks empty, because the internal data of this library wasn't cleared. To make sure
    // that the state of this library is consistent with visual state of the canvas, you
    // have to clear it manually.
    signaturePad.clear();
}

// On mobile devices it might make more sense to listen to orientation change,
// rather than window resize events.
//window.onresize = resizeCanvas;
//resizeCanvas();

function download(dataURL, filename) {
    var blob = dataURLToBlob(dataURL);

    var url = window.URL.createObjectURL(blob);

    var a = document.createElement("a");
    a.style = "display: none";
    a.href = url;
    a.download = filename;

    document.body.appendChild(a);
    // a.click();

    window.URL.revokeObjectURL(url);
}

// One could simply use Canvas#toBlob method instead, but it's just to show
// that it can be done using result of SignaturePad#toDataURL.
function dataURLToBlob(dataURL) {
    // Code taken from https://github.com/ebidel/filer.js
    var parts = dataURL.split(';base64,');
    var contentType = parts[0].split(":")[1];
    var raw = window.atob(parts[1]);
    var rawLength = raw.length;
    var uInt8Array = new Uint8Array(rawLength);

    for (var i = 0; i < rawLength; ++i) {
        uInt8Array[i] = raw.charCodeAt(i);
    }

    return new Blob([uInt8Array], { type: contentType });
}

// Signature pad clear button event.
clearButton.addEventListener("click", function (event) {
    signaturePad.clear();
});

// Signature pad undo button event.
undoButton.addEventListener("click", function (event) {
    var data = signaturePad.toData();

    if (data) {
        data.pop(); // remove the last dot or line
        signaturePad.fromData(data);
    }
});

// Initial pad clear button event.
initialPadClearButton.addEventListener("click", function (event) {
    initialPad.clear();
});

// Initial pad undo button event.
initialPadUndoButton.addEventListener("click", function (event) {
    var data = initialPad.toData();

    if (data) {
        data.pop(); // remove the last dot or line
        initialPad.fromData(data);
    }
});

$("#btnDrawSignInitial").click(function () {

    // Check signature pad and initial pad empty or not.
    if (validatePad() == false) {
        return;
    }

    // Create overlay and append to body:
    $('<div id="overlay"/>').css({
        position: 'fixed',
        top: 0,
        left: 0,
        width: '100%',
        height: $(window).height() + 'px',
        background: 'white url(/Content/img/galaxkey_whitebk_ani.gif) no-repeat center',
        opacity: 0.90
    }).hide().appendTo('body');

    // SHOW overlay
    $('#overlay').show();    

    var dataURL = signaturePad.toDataURL();
    var base64strForSign = dataURL.split('base64,');

    dataURL = initialPad.toDataURL();
    var base64strForInitial = dataURL.split('base64,');

    wholedata = JSON.stringify({
        'signatures': [base64strForSign[1], base64strForInitial[1]],
        'signMethod': 'draw'
    });

    $.ajax({
        type: 'POST',
        url: '/SecureSign/SaveSignatures',
        data: wholedata,
        contentType: 'application/json; charset=utf-8',

        success: function (data) {
            document.open();
            document.write(data);
            document.close();
            $('#overlay').hide();
        },
        //call on ajax call failure
        error: function (xhr, textStatus, error) {
            $('#overlay').hide();
        }
    });
});

function validatePad() {
    if (signaturePad.isEmpty()) {
        showAlert('Signature is required.');
        return false;
    }

    if (initialPad.isEmpty()) {
        showAlert('Initial is required.');
        return false;
    }
}

var fontText = 'Arial';
var fontSize = 16;
var fontWieght = "";
var fontStyle = "";
var fontColor = "black";
var initialFontColor = "black";
var colorSetForSignature = false;
var underline = "";
var initialUnderline = "";
var text = $('#textareaTest').val();

function ddFontChange(isFromSignature) {
    var dFont = document.getElementById(isFromSignature ? 'ddFont' : 'initialFont');
    fontText = dFont.options[dFont.selectedIndex].value;

    $(isFromSignature ? '#textareaTest' : '#textareaTestForInitial').css('font-family', fontText);
}

function ddSizeChange(isFromSignature) {
    var dSize = document.getElementById(isFromSignature ? 'ddSize' : 'initialSize');
    fontSize = dSize.options[dSize.selectedIndex].value;

    $(isFromSignature ? '#textareaTest' : '#textareaTestForInitial').css('font-size', fontSize + "px");
}

function makeBold(isFromSignature) {

    if ($(isFromSignature ? '#btnBold' : '#btnBoldForInitial').hasClass('active1')) {
        $(isFromSignature ? '#textareaTest' : '#textareaTestForInitial').css('font-weight', 'bold');
        fontWieght = "bold";
    }
    else {
        $(isFromSignature ? '#textareaTest' : '#textareaTestForInitial').css('font-weight', 'normal');
        fontWieght = "normal";
    }
}

function goBack() {
    window.history.back();
}

// This method invoke while clicking edit button
function editSign() {
    // Hide sinature preview.
    $('#divPreviewSignature').hide();

    // Show signature methof option.
    $('#divSignMethod').show();    

    // Trigger user signature textbox keyup event to set default preview of the signature
    $('#txtUserSignature').trigger(
       jQuery.Event('keyup', {})
   );

    // Trigger user initial textbox keyup event to set default preview of the initial
    $('#txtUserInitial').trigger(
       jQuery.Event('keyup', {})
    );

    // Signature container
    $('#container').show();
}

$(".btn").click(function () {

    if ($(this).hasClass("active1")) {
        $(this).removeClass("active1");
    } else {
        $(this).addClass("active1");
    }

    makeItalic(this.id == 'btnItalic' ? true : false);
    makeUnderline(this.id == 'btnUnderline' ? true : false);
    makeBold(this.id == 'btnBold' ? true : false);
});

function makeItalic(isFromSignature) {

    if ($(isFromSignature ? '#btnItalic' : '#btnItalicForInitial').hasClass('active1')) {

        $(isFromSignature ? '#textareaTest' : '#textareaTestForInitial').css('font-style', 'italic');
        fontStyle = "italic";
    }
    else {
        $(isFromSignature ? '#textareaTest' : '#textareaTestForInitial').css('font-style', '');
        fontStyle = "";
    }
}

function makeUnderline(isFromSignature) {
    if ($(isFromSignature ? '#btnUnderline' : '#btnUnderlineForInitial').hasClass('active1')) {

        $(isFromSignature ? '#textareaTest' : '#textareaTestForInitial').css('text-decoration', 'Underline');

        if (isFromSignature)
            underline = "Underline";
        else
            initialUnderline = "Underline";
    }
    else {
        $(isFromSignature ? '#textareaTest' : '#textareaTestForInitial').css('text-decoration', '');
        if (isFromSignature)
            underline = "";
        else
            initialUnderline = "";
    }
}

function showColorDialog(isCallFromSignature) {
    colorSetForSignature = isCallFromSignature ? true : false;
    $('#myColors').modal('show');
}

function selectColor(color_this) {

    $(colorSetForSignature ? '#textareaTest' : '#textareaTestForInitial').css('color', color_this.name);
    $(colorSetForSignature ? '#btnColor' : '#btnColorForInitial').css('background-color', color_this.name);

    if (colorSetForSignature)
        fontColor = color_this.name;
    else
        initialFontColor = color_this.name;

    $('#myColors').modal('hide');
}

function saveTextFromArea() {

    var lblSignatureCanvas = document.getElementById('lblSignatureCanvas');
    var lblInitialCanvas = document.getElementById('lblInitialCanvas');

    // Check user weather user has signature and initial enter or not.
    if (document.getElementById('txtUserSignature').value == '') {
        showAlert('Signature is required.');
        document.getElementById('txtUserSignature').focus();
        return;
    } else if (document.getElementById('txtUserInitial').value == '') {
        showAlert('Initial is required.');
        document.getElementById('txtUserInitial').focus();
        return;
    }

    // Create overlay and append to body:
    $('<div id="overlay"/>').css({
        position: 'fixed',
        top: 0,
        left: 0,
        width: '100%',
        height: $(window).height() + 'px',
        background: 'white url(/Content/img/galaxkey_whitebk_ani.gif) no-repeat center',
        opacity: 0.90
    }).hide().appendTo('body');

    // SHOW overlay
    $('#overlay').show();

    if (text != "") {

        var dataURL = lblSignatureCanvas.toDataURL();
        var base64strForSign = dataURL.split('base64,');

        dataURL = lblInitialCanvas.toDataURL();
        var base64strForInitial = dataURL.split('base64,');

        wholedata = JSON.stringify({
            'signatures': [base64strForSign[1], base64strForInitial[1]],
            'signMethod': 'generated'
        });

        $.ajax({
            type: 'POST',
            url: '/SecureSign/SaveSignatures',
            data: wholedata,
            contentType: 'application/json; charset=utf-8',

            success: function (data) {
                document.open();
                document.write(data);
                document.close();
                $('#overlay').hide();
            },
            //call on ajax call failure
            error: function (xhr, textStatus, error) {
                $('#overlay').hide();
            }
        });
    }
}

function showAlert(message) {

    var options = {};
    options['closeButton'] = true;
    options['positionClass'] = "toast-top-center";
    var title = "";
    options['type'] = "error";
    toastr[options.type](message, title, options);
}

$(".btnDiscardConfigSign").click(function () {
    $('#modalCancelConfigureSign').hide();
    window.location.href = "/SecureSign/Index";
});

$("#txtUserSignature").keyup(function () {
    var canvas = document.getElementById('lblSignatureCanvas');    
    var context = canvas.getContext('2d');    
    context.clearRect(0, 0, canvas.width, canvas.height);

    //set the font styles
    var font = 'Mistral';
    var fontsize = 35;
    //var fontweight = shapes[i].wt;
    //var fontstyle = shapes[i].st;
    context.fillStyle = fontColor;

    // Draw the text
    context.font = fontsize + "px " + font;
    context.textAlign = "center";
    context.textBaseline = "middle";
    context.fillText(document.getElementById('txtUserSignature').value, canvas.width / 2, canvas.height / 2);
})

$("#txtUserInitial").keyup(function () {
    var canvas = document.getElementById('lblInitialCanvas');

    var context = canvas.getContext('2d');

    context.clearRect(0, 0, canvas.width, canvas.height);

    //set the font styles
    var font = 'Mistral';
    var fontsize = 35;
    //var fontweight = shapes[i].wt;
    //var fontstyle = shapes[i].st;
    context.fillStyle = initialFontColor;

    // Draw the text
    context.font = fontsize + "px " + font;
    context.textAlign = "center";
    context.textBaseline = "middle";
    context.fillText(document.getElementById('txtUserInitial').value, canvas.width / 2, canvas.height / 2);
})